@@ -7,6 +7,10 @@ class DebugPanel(object):
     # name = Base
     has_content = False # If content returns something, set to true in subclass
 
+    # If the client is able to activate/de-activate the panel
+    user_enable = False
+
+
     # We'll maintain a local context instance so we can expose our template
     # context variables to panels which need them:
     context = {}
@@ -16,6 +20,9 @@ class DebugPanel(object):
         self.context.update(context)
         self.jinja_env = jinja_env
 
+        # If the client enabled the panel
+        self.is_active = False
+
     def render(self, template_name, context):
         template = self.jinja_env.get_template(template_name)
         return template.render(**context)
